<?php

namespace OctolizeShippingAustraliaPostVendor\Octolize\Tracker;

use OctolizeShippingAustraliaPostVendor\WPDesk\PluginBuilder\Plugin\Hookable;
use OctolizeShippingAustraliaPostVendor\WPDesk\PluginBuilder\Plugin\HookableCollection;
use OctolizeShippingAustraliaPostVendor\WPDesk\PluginBuilder\Plugin\HookableParent;
use OctolizeShippingAustraliaPostVendor\WPDesk\Tracker\Deactivation\TrackerFactory;
use OctolizeShippingAustraliaPostVendor\WPDesk\Tracker\OptInOptOut;
/**
 * Can create complete tracker.
 */
class TrackerInitializer implements \OctolizeShippingAustraliaPostVendor\WPDesk\PluginBuilder\Plugin\HookableCollection
{
    use HookableParent;
    /**
     * @var string
     */
    private $plugin_file;
    /**
     * @var string
     */
    private $plugin_slug;
    /**
     * @var string
     */
    private $plugin_name;
    /**
     * @var string
     */
    private $shop_url;
    /**
     * @param string $plugin_file Plugin file.
     * @param string $plugin_slug Plugin slug.
     * @param string $plugin_name Plugin name.
     * @param string $shop_url Shop URL.
     */
    public function __construct(string $plugin_file, string $plugin_slug, string $plugin_name, string $shop_url)
    {
        $this->plugin_file = $plugin_file;
        $this->plugin_slug = $plugin_slug;
        $this->plugin_name = $plugin_name;
        $this->shop_url = $shop_url;
    }
    /**
     * Hooks.
     *
     * @return void
     */
    public function hooks()
    {
        \add_action('plugins_loaded', [$this, 'init_tracker']);
        $this->add_hookable(new \OctolizeShippingAustraliaPostVendor\Octolize\Tracker\SenderRegistrator($this->plugin_slug));
        $opt_in_opt_out = new \OctolizeShippingAustraliaPostVendor\WPDesk\Tracker\OptInOptOut($this->plugin_file, $this->plugin_slug, $this->shop_url, $this->plugin_name);
        $opt_in_opt_out->create_objects();
        $this->add_hookable($opt_in_opt_out);
        $this->add_hookable(\OctolizeShippingAustraliaPostVendor\WPDesk\Tracker\Deactivation\TrackerFactory::createDefaultTracker($this->plugin_slug, $this->plugin_file, $this->plugin_name));
        $this->hooks_on_hookable_objects();
    }
    /**
     * Creates Tracker, Opt-in/Opt-out links on plugins page and deactivation tracker.
     * All data will be sent to https://data.octolize.org
     *
     * @return void
     */
    public function init_tracker()
    {
        $tracker_factory = new \OctolizeShippingAustraliaPostVendor\WPDesk_Tracker_Factory_Prefixed();
        $tracker_factory->create_tracker($this->plugin_slug);
    }
}
