<?php

declare (strict_types=1);
namespace OctolizeShippingAustraliaPostVendor\Http\Client\Common;

use OctolizeShippingAustraliaPostVendor\Http\Promise\Promise;
use OctolizeShippingAustraliaPostVendor\Psr\Http\Client\ClientExceptionInterface;
use Psr\Http\Message\ResponseInterface;
/**
 * A deferred allow to return a promise which has not been resolved yet.
 */
final class Deferred implements \OctolizeShippingAustraliaPostVendor\Http\Promise\Promise
{
    /**
     * @var ResponseInterface|null
     */
    private $value;
    /**
     * @var ClientExceptionInterface|null
     */
    private $failure;
    /**
     * @var string
     */
    private $state;
    /**
     * @var callable
     */
    private $waitCallback;
    /**
     * @var callable[]
     */
    private $onFulfilledCallbacks;
    /**
     * @var callable[]
     */
    private $onRejectedCallbacks;
    public function __construct(callable $waitCallback)
    {
        $this->waitCallback = $waitCallback;
        $this->state = \OctolizeShippingAustraliaPostVendor\Http\Promise\Promise::PENDING;
        $this->onFulfilledCallbacks = [];
        $this->onRejectedCallbacks = [];
    }
    /**
     * {@inheritdoc}
     */
    public function then(callable $onFulfilled = null, callable $onRejected = null) : \OctolizeShippingAustraliaPostVendor\Http\Promise\Promise
    {
        $deferred = new self($this->waitCallback);
        $this->onFulfilledCallbacks[] = function (\Psr\Http\Message\ResponseInterface $response) use($onFulfilled, $deferred) {
            try {
                if (null !== $onFulfilled) {
                    $response = $onFulfilled($response);
                }
                $deferred->resolve($response);
            } catch (\OctolizeShippingAustraliaPostVendor\Psr\Http\Client\ClientExceptionInterface $exception) {
                $deferred->reject($exception);
            }
        };
        $this->onRejectedCallbacks[] = function (\OctolizeShippingAustraliaPostVendor\Psr\Http\Client\ClientExceptionInterface $exception) use($onRejected, $deferred) {
            try {
                if (null !== $onRejected) {
                    $response = $onRejected($exception);
                    $deferred->resolve($response);
                    return;
                }
                $deferred->reject($exception);
            } catch (\OctolizeShippingAustraliaPostVendor\Psr\Http\Client\ClientExceptionInterface $newException) {
                $deferred->reject($newException);
            }
        };
        return $deferred;
    }
    /**
     * {@inheritdoc}
     */
    public function getState() : string
    {
        return $this->state;
    }
    /**
     * Resolve this deferred with a Response.
     */
    public function resolve(\Psr\Http\Message\ResponseInterface $response) : void
    {
        if (\OctolizeShippingAustraliaPostVendor\Http\Promise\Promise::PENDING !== $this->state) {
            return;
        }
        $this->value = $response;
        $this->state = \OctolizeShippingAustraliaPostVendor\Http\Promise\Promise::FULFILLED;
        foreach ($this->onFulfilledCallbacks as $onFulfilledCallback) {
            $onFulfilledCallback($response);
        }
    }
    /**
     * Reject this deferred with an Exception.
     */
    public function reject(\OctolizeShippingAustraliaPostVendor\Psr\Http\Client\ClientExceptionInterface $exception) : void
    {
        if (\OctolizeShippingAustraliaPostVendor\Http\Promise\Promise::PENDING !== $this->state) {
            return;
        }
        $this->failure = $exception;
        $this->state = \OctolizeShippingAustraliaPostVendor\Http\Promise\Promise::REJECTED;
        foreach ($this->onRejectedCallbacks as $onRejectedCallback) {
            $onRejectedCallback($exception);
        }
    }
    /**
     * {@inheritdoc}
     */
    public function wait($unwrap = \true)
    {
        if (\OctolizeShippingAustraliaPostVendor\Http\Promise\Promise::PENDING === $this->state) {
            $callback = $this->waitCallback;
            $callback();
        }
        if (!$unwrap) {
            return null;
        }
        if (\OctolizeShippingAustraliaPostVendor\Http\Promise\Promise::FULFILLED === $this->state) {
            return $this->value;
        }
        /** @var ClientExceptionInterface */
        throw $this->failure;
    }
}
