<?php

declare (strict_types=1);
namespace OctolizeShippingAustraliaPostVendor\Http\Client\Common\Plugin;

use OctolizeShippingAustraliaPostVendor\Http\Client\Common\Plugin;
use OctolizeShippingAustraliaPostVendor\Http\Message\RequestMatcher;
use OctolizeShippingAustraliaPostVendor\Http\Promise\Promise;
use Psr\Http\Message\RequestInterface;
/**
 * Apply a delegated plugin based on a request match.
 *
 * @author Márk Sági-Kazár <mark.sagikazar@gmail.com>
 */
final class RequestMatcherPlugin implements \OctolizeShippingAustraliaPostVendor\Http\Client\Common\Plugin
{
    /**
     * @var RequestMatcher
     */
    private $requestMatcher;
    /**
     * @var Plugin|null
     */
    private $successPlugin;
    /**
     * @var Plugin|null
     */
    private $failurePlugin;
    public function __construct(\OctolizeShippingAustraliaPostVendor\Http\Message\RequestMatcher $requestMatcher, ?\OctolizeShippingAustraliaPostVendor\Http\Client\Common\Plugin $delegateOnMatch, \OctolizeShippingAustraliaPostVendor\Http\Client\Common\Plugin $delegateOnNoMatch = null)
    {
        $this->requestMatcher = $requestMatcher;
        $this->successPlugin = $delegateOnMatch;
        $this->failurePlugin = $delegateOnNoMatch;
    }
    /**
     * {@inheritdoc}
     */
    public function handleRequest(\Psr\Http\Message\RequestInterface $request, callable $next, callable $first) : \OctolizeShippingAustraliaPostVendor\Http\Promise\Promise
    {
        if ($this->requestMatcher->matches($request)) {
            if (null !== $this->successPlugin) {
                return $this->successPlugin->handleRequest($request, $next, $first);
            }
        } elseif (null !== $this->failurePlugin) {
            return $this->failurePlugin->handleRequest($request, $next, $first);
        }
        return $next($request);
    }
}
