<?php

declare (strict_types=1);
namespace OctolizeShippingAustraliaPostVendor\Http\Client\Common;

use OctolizeShippingAustraliaPostVendor\Http\Client\Exception as HttplugException;
use OctolizeShippingAustraliaPostVendor\Http\Client\HttpAsyncClient;
use OctolizeShippingAustraliaPostVendor\Http\Client\HttpClient;
use OctolizeShippingAustraliaPostVendor\Http\Client\Promise\HttpFulfilledPromise;
use OctolizeShippingAustraliaPostVendor\Http\Client\Promise\HttpRejectedPromise;
use OctolizeShippingAustraliaPostVendor\Http\Promise\Promise;
use OctolizeShippingAustraliaPostVendor\Psr\Http\Client\ClientInterface;
use Psr\Http\Message\RequestInterface;
use Psr\Http\Message\ResponseInterface;
use OctolizeShippingAustraliaPostVendor\Symfony\Component\OptionsResolver\OptionsResolver;
/**
 * The client managing plugins and providing a decorator around HTTP Clients.
 *
 * @author Joel Wurtz <joel.wurtz@gmail.com>
 */
final class PluginClient implements \OctolizeShippingAustraliaPostVendor\Http\Client\HttpClient, \OctolizeShippingAustraliaPostVendor\Http\Client\HttpAsyncClient
{
    /**
     * An HTTP async client.
     *
     * @var HttpAsyncClient
     */
    private $client;
    /**
     * The plugin chain.
     *
     * @var Plugin[]
     */
    private $plugins;
    /**
     * A list of options.
     *
     * @var array
     */
    private $options;
    /**
     * @param ClientInterface|HttpAsyncClient $client  An HTTP async client
     * @param Plugin[]                        $plugins A plugin chain
     * @param array{'max_restarts'?: int}     $options
     */
    public function __construct($client, array $plugins = [], array $options = [])
    {
        if ($client instanceof \OctolizeShippingAustraliaPostVendor\Http\Client\HttpAsyncClient) {
            $this->client = $client;
        } elseif ($client instanceof \OctolizeShippingAustraliaPostVendor\Psr\Http\Client\ClientInterface) {
            $this->client = new \OctolizeShippingAustraliaPostVendor\Http\Client\Common\EmulatedHttpAsyncClient($client);
        } else {
            throw new \TypeError(\sprintf('%s::__construct(): Argument #1 ($client) must be of type %s|%s, %s given', self::class, \OctolizeShippingAustraliaPostVendor\Psr\Http\Client\ClientInterface::class, \OctolizeShippingAustraliaPostVendor\Http\Client\HttpAsyncClient::class, \get_debug_type($client)));
        }
        $this->plugins = $plugins;
        $this->options = $this->configure($options);
    }
    /**
     * {@inheritdoc}
     */
    public function sendRequest(\Psr\Http\Message\RequestInterface $request) : \Psr\Http\Message\ResponseInterface
    {
        // If the client doesn't support sync calls, call async
        if (!$this->client instanceof \OctolizeShippingAustraliaPostVendor\Psr\Http\Client\ClientInterface) {
            return $this->sendAsyncRequest($request)->wait();
        }
        // Else we want to use the synchronous call of the underlying client,
        // and not the async one in the case we have both an async and sync call
        $pluginChain = $this->createPluginChain($this->plugins, function (\Psr\Http\Message\RequestInterface $request) {
            try {
                return new \OctolizeShippingAustraliaPostVendor\Http\Client\Promise\HttpFulfilledPromise($this->client->sendRequest($request));
            } catch (\OctolizeShippingAustraliaPostVendor\Http\Client\Exception $exception) {
                return new \OctolizeShippingAustraliaPostVendor\Http\Client\Promise\HttpRejectedPromise($exception);
            }
        });
        return $pluginChain($request)->wait();
    }
    /**
     * {@inheritdoc}
     */
    public function sendAsyncRequest(\Psr\Http\Message\RequestInterface $request)
    {
        $pluginChain = $this->createPluginChain($this->plugins, function (\Psr\Http\Message\RequestInterface $request) {
            return $this->client->sendAsyncRequest($request);
        });
        return $pluginChain($request);
    }
    /**
     * Configure the plugin client.
     */
    private function configure(array $options = []) : array
    {
        $resolver = new \OctolizeShippingAustraliaPostVendor\Symfony\Component\OptionsResolver\OptionsResolver();
        $resolver->setDefaults(['max_restarts' => 10]);
        $resolver->setAllowedTypes('max_restarts', 'int');
        return $resolver->resolve($options);
    }
    /**
     * Create the plugin chain.
     *
     * @param Plugin[] $plugins        A plugin chain
     * @param callable $clientCallable Callable making the HTTP call
     *
     * @return callable(RequestInterface): Promise
     */
    private function createPluginChain(array $plugins, callable $clientCallable) : callable
    {
        /** @var callable(RequestInterface): Promise */
        return new \OctolizeShippingAustraliaPostVendor\Http\Client\Common\PluginChain($plugins, $clientCallable, $this->options);
    }
}
